@@ -1,6 +1,7 @@
 package main_test
 
 import (
+	"encoding/json"
 	"fmt"
 	"io"
 	"net/http"
@@ -56,7 +57,64 @@ func TestBreakdownFormatJsonWithWarnings(t *testing.T) {
 			"--format", "json",
 			"--path", dir,
 		},
-		&GoldenFileOptions{CaptureLogs: true},
+		&GoldenFileOptions{
+			CaptureLogs: true,
+			IsJSON:      true,
+		},
+	)
+}
+
+func TestBreakdownFormatJsonWithTags(t *testing.T) {
+	testName := testutil.CalcGoldenFileTestdataDirName()
+	dir := path.Join("./testdata", testName)
+	GoldenFileCommandTest(
+		t,
+		testName,
+		[]string{
+			"breakdown",
+			"--format", "json",
+			"--path", dir,
+		},
+		&GoldenFileOptions{
+			CaptureLogs: true,
+			IsJSON:      true,
+		},
+	)
+}
+
+func TestBreakdownFormatJsonWithTagsAzure(t *testing.T) {
+	testName := testutil.CalcGoldenFileTestdataDirName()
+	dir := path.Join("./testdata", testName)
+	GoldenFileCommandTest(
+		t,
+		testName,
+		[]string{
+			"breakdown",
+			"--format", "json",
+			"--path", dir,
+		},
+		&GoldenFileOptions{
+			CaptureLogs: true,
+			IsJSON:      true,
+		},
+	)
+}
+
+func TestBreakdownFormatJsonWithTagsGoogle(t *testing.T) {
+	testName := testutil.CalcGoldenFileTestdataDirName()
+	dir := path.Join("./testdata", testName)
+	GoldenFileCommandTest(
+		t,
+		testName,
+		[]string{
+			"breakdown",
+			"--format", "json",
+			"--path", dir,
+		},
+		&GoldenFileOptions{
+			CaptureLogs: true,
+			IsJSON:      true,
+		},
 	)
 }
 
@@ -101,7 +159,10 @@ func TestBreakdownConfigFile(t *testing.T) {
 			"breakdown",
 			"--config-file", path.Join(dir, "infracost.yml"),
 			"--format", "json",
-		}, nil,
+		},
+		&GoldenFileOptions{
+			IsJSON: true,
+		},
 	)
 }
 
@@ -239,6 +300,27 @@ func TestBreakdownTerraformOutFileJSON(t *testing.T) {
 
 	GoldenFileCommandTest(t, testdataName, []string{"breakdown", "--path", "./testdata/example_plan.json", "--format", "json", "--out-file", outputPath}, nil)
 
+	// prettify the output
+	file, err := os.ReadFile(outputPath)
+	if err != nil {
+		t.Error(err)
+		return
+	}
+
+	data := map[string]interface{}{}
+	err = json.Unmarshal(file, &data)
+	if err != nil {
+		t.Error(err)
+		return
+	}
+
+	pretty, _ := json.MarshalIndent(data, "", "  ")
+	err = os.WriteFile(outputPath, pretty, 0600)
+	if err != nil {
+		t.Error(err)
+		return
+	}
+
 	actual, err := os.ReadFile(outputPath)
 	require.Nil(t, err)
 	actual = stripDynamicValues(actual)
@@ -658,6 +740,21 @@ func TestBreakdownWithActualCosts(t *testing.T) {
 	)
 }
 
+func TestBreakdownWithDefaultTags(t *testing.T) {
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"breakdown",
+			"--path", path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName()),
+			"--format", "json",
+		},
+		&GoldenFileOptions{
+			IsJSON: true,
+		},
+	)
+}
+
 func TestBreakdownWithNestedForeach(t *testing.T) {
 	GoldenFileCommandTest(
 		t,
@@ -749,7 +846,10 @@ func TestBreakdownMultiProjectWithErrorOutputJSON(t *testing.T) {
 			dir,
 			"--format",
 			"json",
-		}, &GoldenFileOptions{CaptureLogs: true},
+		}, &GoldenFileOptions{
+			CaptureLogs: true,
+			IsJSON:      true,
+		},
 	)
 }
 
@@ -778,3 +878,30 @@ func TestBreakdownWithLocalPathDataBlock(t *testing.T) {
 		}, &GoldenFileOptions{CaptureLogs: true},
 	)
 }
+
+func TestBreakdownAutoWithMultiVarfileProjects(t *testing.T) {
+	testName := testutil.CalcGoldenFileTestdataDirName()
+	dir := path.Join("./testdata", testName)
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"breakdown",
+			"--path", dir,
+		}, nil)
+}
+
+func TestBreakdownWithFreeResourcesChecksum(t *testing.T) {
+	testName := testutil.CalcGoldenFileTestdataDirName()
+	dir := path.Join("./testdata", testName)
+	GoldenFileCommandTest(
+		t,
+		testutil.CalcGoldenFileTestdataDirName(),
+		[]string{
+			"breakdown",
+			"--path", dir,
+			"--format", "json",
+		}, &GoldenFileOptions{IsJSON: true}, func(ctx *config.RunContext) {
+			ctx.Config.TagPoliciesEnabled = true
+		})
+}
