@@ -104,7 +104,7 @@ func commentGitHubCmd(ctx *config.RunContext) *cobra.Command {
 
 			paths, _ := cmd.Flags().GetStringArray("path")
 
-			body, hasDiff, err := buildCommentBody(cmd, ctx, paths, output.MarkdownOptions{
+			commentOut, err := buildCommentOutput(cmd, ctx, paths, output.MarkdownOptions{
 				WillUpdate:          prNumber != 0 && behavior == "update",
 				WillReplace:         prNumber != 0 && behavior == "delete-and-new",
 				IncludeFeedbackLink: !ctx.Config.IsSelfHosted(),
@@ -129,7 +129,10 @@ func commentGitHubCmd(ctx *config.RunContext) *cobra.Command {
 			if !dryRun {
 				skipNoDiff, _ := cmd.Flags().GetBool("skip-no-diff")
 
-				posted, err := commentHandler.CommentWithBehavior(ctx.Context(), !hasDiff && skipNoDiff, behavior, string(body))
+				res, err := commentHandler.CommentWithBehavior(ctx.Context(), behavior, commentOut.Body, &comment.CommentOpts{
+					ValidAt:    commentOut.ValidAt,
+					SkipNoDiff: !commentOut.HasDiff && skipNoDiff,
+				})
 				if err != nil {
 					return err
 				}
@@ -140,13 +143,17 @@ func commentGitHubCmd(ctx *config.RunContext) *cobra.Command {
 					logging.Logger.WithError(err).Error("could not report infracost-comment event")
 				}
 
-				if posted {
+				if res.Posted {
 					cmd.Println("Comment posted to GitHub")
 				} else {
-					cmd.Println("Comment not posted to GitHub (skipped)")
+					msg := "Comment not posted to GitHub"
+					if res.SkipReason != "" {
+						msg += fmt.Sprintf(": %s", res.SkipReason)
+					}
+					cmd.Println(msg)
 				}
 			} else {
-				cmd.Println(string(body))
+				cmd.Println(commentOut.Body)
 				cmd.Println("Comment not posted to GitHub (--dry-run was specified)")
 			}
 
