@@ -49,7 +49,13 @@ func (c *Context) Root() *Context {
 	return root
 }
 
-func (c *Context) Get(parts ...string) cty.Value {
+func (c *Context) Get(parts ...string) (val cty.Value) {
+	defer func() {
+		if val == cty.NilVal && c.Parent() != nil {
+			val = c.Parent().Get(parts...)
+		}
+	}()
+
 	if len(parts) == 0 {
 		return cty.NilVal
 	}
