@@ -191,6 +191,7 @@ func CompareTo(c *config.Config, current, prior Root) (Root, error) {
 func Combine(inputs []ReportInput) (Root, error) {
 	var combined Root
 
+	var lastestGeneratedAt time.Time
 	var totalHourlyCost *decimal.Decimal
 	var totalMonthlyCost *decimal.Decimal
 	var pastTotalHourlyCost *decimal.Decimal
@@ -217,6 +218,10 @@ func Combine(inputs []ReportInput) (Root, error) {
 
 		summaries = append(summaries, input.Root.Summary)
 
+		if input.Root.TimeGenerated.After(lastestGeneratedAt) {
+			lastestGeneratedAt = input.Root.TimeGenerated
+		}
+
 		if len(input.Root.TagPolicies) > 0 {
 			tagPolicies = append(tagPolicies, input.Root.TagPolicies...)
 		}
@@ -282,7 +287,7 @@ func Combine(inputs []ReportInput) (Root, error) {
 	combined.PastTotalMonthlyCost = pastTotalMonthlyCost
 	combined.DiffTotalHourlyCost = diffTotalHourlyCost
 	combined.DiffTotalMonthlyCost = diffTotalMonthlyCost
-	combined.TimeGenerated = time.Now().UTC()
+	combined.TimeGenerated = lastestGeneratedAt
 	combined.Summary = MergeSummaries(summaries)
 	combined.Metadata = metadata
 	combined.TagPolicies = mergeTagPolicies(tagPolicies)
