@@ -64,14 +64,14 @@ func Detect(ctx *config.ProjectContext, includePastResources bool) (schema.Provi
 			return nil, providerErr
 		}
 
-		if err := validateProjectForHCL(ctx, path); err != nil {
+		if err := validateProjectForHCL(ctx); err != nil {
 			return h, err
 		}
 
 		return h, nil
 	case "terragrunt_dir":
 		h := terraform.NewTerragruntHCLProvider(ctx, includePastResources)
-		if err := validateProjectForHCL(ctx, path); err != nil {
+		if err := validateProjectForHCL(ctx); err != nil {
 			return h, err
 		}
 
@@ -93,22 +93,22 @@ func Detect(ctx *config.ProjectContext, includePastResources bool) (schema.Provi
 	return nil, fmt.Errorf("could not detect path type for '%s'", path)
 }
 
-func validateProjectForHCL(ctx *config.ProjectContext, path string) error {
+func validateProjectForHCL(ctx *config.ProjectContext) error {
 	if ctx.ProjectConfig.TerraformInitFlags != "" {
 		return &ValidationError{
-			err: "Flag terraform-init-flags is deprecated and only compatible with --terraform-force-cli.",
+			warn: "Flag terraform-init-flags is deprecated and only compatible with --terraform-force-cli.",
 		}
 	}
 
 	if ctx.ProjectConfig.TerraformPlanFlags != "" {
 		return &ValidationError{
-			err: "Flag terraform-plan-flags is deprecated and only compatible with --terraform-force-cli. If you want to pass Terraform variables use the --terraform-vars or --terraform-var-file flag.",
+			warn: "Flag terraform-plan-flags is deprecated and only compatible with --terraform-force-cli. If you want to pass Terraform variables use the --terraform-vars or --terraform-var-file flag.",
 		}
 	}
 
 	if ctx.ProjectConfig.TerraformUseState {
 		return &ValidationError{
-			err: "Flag terraform-use-state is deprecated and only compatible with --terraform-force-cli.",
+			warn: "Flag terraform-use-state is deprecated and only compatible with --terraform-force-cli.",
 		}
 	}
 
